==> dioptas_0.5.2.orig.tar.gz: Dioptas-0.5.2/dioptas/controller/integration/__init__.py <==
# -*- coding: utf-8 -*-
# Dioptas - GUI program for fast processing of 2D X-ray diffraction data
# Principal author: Clemens Prescher (clemens.prescher@gmail.com)
# Copyright (C) 2014-2019 GSECARS, University of Chicago, USA
# Copyright (C) 2015-2018 Institute for Geology and Mineralogy, University of Cologne, Germany
# Copyright (C) 2019-2020 DESY, Hamburg, Germany
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .BackgroundController import BackgroundController
from .ImageController import ImageController
from .IntegrationController import IntegrationController
from .phase.JcpdsEditorController import JcpdsEditorController
from .OverlayController import OverlayController
from .phase.PhaseController import PhaseController
from .phase.PhaseController import PhaseInPatternController
from .phase.PhaseInCakeController import PhaseInCakeController
from .PatternController import PatternController
from .OptionsController import OptionsController

==> dioptas_0.6.0.orig.tar.gz: Dioptas-0.6.0/dioptas/controller/integration/__init__.py <==
# -*- coding: utf-8 -*-
# Dioptas - GUI program for fast processing of 2D X-ray diffraction data
# Principal author: Clemens Prescher (clemens.prescher@gmail.com)
# Copyright (C) 2014-2019 GSECARS, University of Chicago, USA
# Copyright (C) 2015-2018 Institute for Geology and Mineralogy, University of Cologne, Germany
# Copyright (C) 2019-2020 DESY, Hamburg, Germany
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .BackgroundController import BackgroundController
from .ImageController import ImageController
from .IntegrationController import IntegrationController
from .phase.JcpdsEditorController import JcpdsEditorController
from .overlay.OverlayController import OverlayController
from .phase.PhaseController import PhaseController
from .phase.PhaseController import PhaseInPatternController
from .phase.PhaseInCakeController import PhaseInCakeController
from .PatternController import PatternController
from .MapController import MapController
from .OptionsController import OptionsController
from .BatchController import BatchController
